<?php
/*
Plugin Name: Promotion Slider
Plugin URI: http://www.orderofbusiness.net/plugins/promotion-slider/
Description: This plugin creates a special post type called 'Promotions' that it uses to populate the carousel.  Just use the shortcode [promoslider] to display the slider on your site.  Be sure to check the <a href="http://wordpress.org/extend/plugins/promotion-slider/faq/" target="_blank">user guide</a> for more information on what this plugin can really do!
Version: 2.2.1
Author: Micah Wood
Author URI: http://www.orderofbusiness.net/micah-wood/
License: GPL2
*/

/*
Copyright 2010  Micah Wood  (email : micah.wood@orderofbusiness.net)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

if( !defined('PROMOSLIDER_PATH') ) define( 'PROMOSLIDER_PATH', dirname(__FILE__) );
if( !defined('PROMOSLIDER_URL') ) define( 'PROMOSLIDER_URL', get_bloginfo('wpurl').'/wp-content/plugins/promotion-slider' );

if( !class_exists('promo_slider') ){
  class promo_slider{
	  
	  // Define post type that we will pull from
	  private $post_type = 'promotion';
	  private $taxonomy_name = 'promotion-categories';
	  
	  function __construct(){
		  
		  // Create the post type that we will pull from
		  include('includes/SD_Register_Post_Type.php');
		  $args = array('register_meta_box_cb' => array(&$this, 'meta_box') );
		  new SD_Register_Post_Type($this->post_type, $args);
		  
		  // Flush rewrite rules once after adding new post type
		  register_activation_hook( __FILE__, array(&$this, 'activate') );
		  
		  // Initiate key components
		  add_action( 'init', array(&$this, 'init') );
		  add_action( 'admin_menu', array(&$this, 'admin_menu') );

	  }
	  
	  function init(){
		  
		  // Add theme support for post thumbnails
		  add_theme_support( 'post-thumbnails' );
		  
		  // Ensure that jquery is loaded
		  wp_enqueue_script( 'jquery' );
		  
		  // Register and load our jquery file
		  wp_register_script( 'promoslider_main', PROMOSLIDER_URL.'/includes/promo_slider.js' );
		  wp_enqueue_script( 'promoslider_main' );
		  
		  // Register and load our css file
		  wp_register_style( 'promoslider_main', PROMOSLIDER_URL.'/css/slide.css' );
		  wp_enqueue_style( 'promoslider_main' );
		  
		  // Localize plugin options
		  $data = array( 'timeDelay' => get_option('time_delay'), 'noAutoAdvance' => get_option('no_auto_advance') );
		  wp_localize_script('promoslider_main', 'promoslider_options', $data);
		  
		  // Create [promoslider] shortcode
		  add_shortcode( 'promoslider', array(&$this, 'show') );
		  
		  // Save meta data when saving promotions
		  add_action( 'save_post', array(&$this, 'save_meta_data') );
		  
		  // Register taxonomy for promotions
		  register_taxonomy( $this->taxonomy_name, array($this->post_type), array(
			  'hierarchical' => true,
			  'labels' => array( 'name' => __('Categories'),
								'singular_name' => __('Category'),
								'search_items' => __('Search Categories'),
								'all_items' => __('All Categories'),
								'parent_item' => __('Parent Category'),
								'parent_item_colon' => __('Parent Category:'),
								'edit_item' => __('Edit Category'),
								'update_item' => __('Update Category'),
								'add_new_item' => __('Add New Category') ),
			  'show_ui' => true,
			  'query_var' => true,
			  'rewrite' => array( 'slug' => 'promotions' )
		  ));
	  }
	  
	  function admin_menu(){
		// Create options page
		add_submenu_page( 'edit.php?post_type=promotion', __('Promotion Slider Options'), __('Slider Options'), 'manage_options', 'options', array(&$this, 'options_page') );
		// Register settings using our function
		add_action( 'admin_init', array(&$this, 'register_settings') );
	  }
	  
	  function register_settings(){
		// Register plugin options
		register_setting( 'promoslider-settings-group', 'time_delay' );
		register_setting( 'promoslider-settings-group', 'no_auto_advance' );
	  }
	  
	  function options_page(){ ?>
        <div class="wrap">
          <h2>Promotion Slider Options</h2>
          
          <form method="post" action="options.php">
              
			  <?php 
				settings_fields( 'promoslider-settings-group' ); 
				
				// Get time delay
				$delay = get_option('time_delay');
				// If delay is not set, be sure form displays default time delay
				if(!$delay) $delay = 6;
				// Get auto advance variable
				$no_auto = get_option('no_auto_advance'); 
			  ?>
              
              <table class="form-table">
                <tr valign="top">
                  <th scope="row">Set Slider Time Delay</th>
                  <td>
                    <select name="time_delay">
                      <?php for($i=3; $i<=15; $i++): ?>
                        <option value="<?php echo $i; ?>"<?php if( $delay == $i ) echo 'selected="selected"'; ?>><?php echo $i; ?> Seconds</option>
                      <?php endfor; ?>
                    </select>
                  </td>
                </tr>
                 
                <tr valign="top">
                  <th scope="row">Automatic Slide Advancement</th>
                  <td>
                    <input type="checkbox" name="no_auto_advance" value="true" <?php if( $no_auto == true ) echo 'checked="checked"'; ?> /> 
                    <?php _e('Check to disable'); ?>
                  </td>
                </tr>
              </table>
              
              <p class="submit">
                <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
              </p>
          
          </form>
        </div>
		
		<style type="text/css">
		  #support{border:1px solid #000; padding:5px 10px 10px 10px; width:500px; margin-top:50px;}
		  #support li{list-style-type:disc; margin-left:25px;}
        </style>
        
        <div id="support" class="wrap">
          <h3>Support This Plugin</h3>
          <p>If you have found this plugin helpful, please consider:
            <ul>
              <li>Linking to our site: <a href="http://www.orderofbusiness.net/" target="_blank">http://www.orderofbusiness.net/</a></li>
              <li>Making a donation</li>
            </ul>
          </p>
          <form action="https://www.paypal.com/cgi-bin/webscr" method="post">
            <input type="hidden" name="cmd" value="_s-xclick">
            <input type="hidden" name="hosted_button_id" value="ZWYWE2TQLXBJY">
            <input type="image" src="https://www.paypal.com/en_US/i/btn/btn_donateCC_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
            <img alt="" border="0" src="https://www.paypal.com/en_US/i/scr/pixel.gif" width="1" height="1">
          </form>
        </div><?php
	  }
	  
	  function show( $atts ){
		// Extract shortcode attributes and set defaults
		extract( shortcode_atts(array('id' => NULL, 'post_type' => 'promotion', 'category' => NULL), $atts) );
		
		// Make $post global and save current value so we can restore it later
		global $post; 
		$tmp_post = $post;
		
		// Create an empty array that we can use to build our query
		$query = array();
		
		// Set the post type that we will be looking for.  If post type is invalid, use the default
		if( post_type_exists($post_type) ) $query['post_type'] = $post_type;
		else $query['post_type'] = $this->post_type;
		
		// Check to see if the category is set and the term exists.  If it exists and the post type is post or the default, set the category based on taxonomy.
		if( !empty($category) && term_exists($category) ){
		  if( $query['post_type'] == $this->post_type ) $query[$this->taxonomy_name] = $category;
		  elseif( $query['post_type'] == 'post' ) $query['category'];
		}
		
		// Use the promoslider_query filter to customize the results returned.  You can use the id to customize any particular slider query.
		$query = apply_filters('promoslider_query', $query, $id);
		
		// Run query and get posts
		$promo_posts = get_posts( $query );
		
		// If there are results, build slider.  Otherwise, don't show anything.
		if($promo_posts): $i = 1; ?>
		
		<div <?php if( isset($id) ) echo 'id="'.$id.'" '; ?>class="promo_slider">
		  
		  <?php foreach($promo_posts as $post): setup_postdata($post);
		    // Get the title
			$title = get_the_title(); 
			// Get the excerpt
			$excerpt = get_the_excerpt();
			// Get the thumbnail, if any
			if( function_exists('has_post_thumbnail') && has_post_thumbnail($post->ID) ) $thumb = get_the_post_thumbnail($post->ID, 'full');
			else $thumb = NULL;
			// If the destination url is set by the user, use that.  Otherwise, use the permalink
			if( !$dest_url = get_post_meta($post->ID, '_promo_slider_url', TRUE) ){ $dest_url = get_permalink($post->ID); }
			// If the target attribute is set the user, use that.  Otherwise, set it to _self
			if( !$target = get_post_meta($post->ID, '_promo_slider_target', TRUE) ){ $target = '_self'; } 
			// Store all the values in an array and pass it to the promoslider_content action
			$values = array('title' => $title, 'excerpt' => $excerpt, 'image' => $thumb, 'destination_url' => $dest_url, 'target' => $target, 'id' => $id); ?>
						
			<div class="panel panel-<?php echo $i; ?>" value="<?php echo $i; ?>">
			  <?php // Use the promoslider_content action to populate the contents for panel
			  do_action('promoslider_content', $values); ?>
			</div>
			  
			<?php $i++; ?>
		  <?php endforeach; 
		  
		  // Restore original value of $post global variable for later use by WordPress
		  $post = $tmp_post; ?>
			  
		  <?php if($i > 2): ?>
			<?php // Use promoslider_nav action to generate the nav options
			do_action('promoslider_nav'); ?>
		  <?php endif; ?>
			
		  <div class="clear"></div>
			
		</div><?php endif;
	  }
	  
	  function meta_box() {
		  // Add the meta box for promotions so users can customize the destination urls
		  add_meta_box( 'promo_slider_meta_box', __('Set Destination URL (Optional)'), array(&$this, 'meta_box_content'), $this->post_type );
	  }
	  
	  function meta_box_content() {
		  global $post;
		  
		  // Use nonce for verification
		  wp_nonce_field( 'ps_update_promotion', 'promo_slider_noncename' ); 
		  
		  // The actual fields for data entry  ?>
		  <p>If you would like to have the link in the slider point somewhere besides this promotion, enter the desired URL here:</p>
		  <!-- Destination URL -->
          <label for="_promo_slider_url"><?php _e('Destination URL: ') ?></label> 
		  <input type="text" id= "_promo_slider_url" name="_promo_slider_url" value="<?php $value = get_post_meta($post->ID, '_promo_slider_url', TRUE); if(!empty($value)) echo $value; ?>" size="75" />
		  <br />
		  <!-- Link Target Attribute -->
          <label for="_promo_slider_target">Select the behaviour for this link: </label>
		  <?php $target = get_post_meta($post->ID, '_promo_slider_target', TRUE); $selected = ' selected="selected"'; ?>
		  <select name="_promo_slider_target">
			<option value=""<?php if( empty($target) ) echo $selected; ?>><?php _e('-- Choose One --'); ?></option>
			<option value="_self"<?php if( $target == '_self' ) echo $selected; ?>><?php _e('Open link in same page'); ?></option>
			<option value="_blank"<?php if( $target == '_blank' ) echo $selected; ?>><?php _e('Open link in a new page'); ?></option>
		  </select>
		  <?php
	  }
	  
	  function save_meta_data( $post_id ) {
  
		  // If this is an auto save, our form has not been submitted, so we don't want to do anything
		  if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) return $post_id;
		  
		  // Is the post type correct?
		  if ( $this->post_type != $_POST['post_type'] ) return $post_id;
		  
		  // Verify this came from our screen and with proper authorization, because save_post can be triggered at other times
		  if ( !wp_verify_nonce( $_POST['promo_slider_noncename'], 'ps_update_promotion' )) { return $post_id; }
			
		  // Can user edit this post?
		  if ( !current_user_can('edit_post', $post_id) ) return $post_id;
		
		  // OK, we're authenticated - find and save the data		
		  $data = array('_promo_slider_url', '_promo_slider_target');
		  
		  // Use this filter to add postmeta to save for the default post type
		  $data = apply_filter('promoslider_add_meta_to_save', $data);
		  
		  foreach($data as $meta){
			  // Get current meta
			  $current = get_post_meta($post_id, $meta, TRUE);
			  // Get new meta
			  $new = $_POST[$meta];
			  
			  // If the new meta is empty, delete the current meta
			  if( empty($new) ) delete_post_meta($post_id, $meta);
			  // Otherwise, update the current meta
			  else update_post_meta($post_id, $meta, $new);
		  }
	  }
	  	  
	  function activate() {
		// One time flush of rewrite rules
		flush_rewrite_rules();
	  }
	  
  }
}

function promoslider_display_image($values){
  extract($values);
  if( $image ) echo '<div class="promo_slider_background_image"><a href="'.$destination_url.'" target="'.$target.'">'.$image.'</a></div>';
}
// Add action to display image
add_action('promoslider_content', 'promoslider_display_image');

function promoslider_display_title($values){
  extract($values);
  if( $title ) echo '<div class="promo_slider_title"><a href="'.$destination_url.'" target="'.$target.'">'.$title.'</a></div>';
}
// Add action to display title
//add_action('promoslider_content', 'promoslider_display_title');

function promoslider_display_excerpt($values){
  extract($values);
  if($excerpt) echo '<div class="promo_slider_excerpt">'.$excerpt.'</div>';
}
// Add action to display excerpt
//add_action('promoslider_content', 'promoslider_display_excerpt');

function promoslider_display_nav(){
  echo '<div class="promo_slider_nav">
	<span class="move_backward pointer" title="Move Backward">&lt;&lt;</span>
	<span class="slider_selections pointer"></span>
	<span class="move_forward pointer" title="Move Forward">&gt;&gt;</span>
  </div>';
}
// Add action to display nav
add_action('promoslider_nav', 'promoslider_display_nav');

global $promo_slider;
$promo_slider = new promo_slider();

?>